Getting started

### Navigation

- index
- next |
- previous |
- fantastico 0.1.0-b1 documentation »

# Getting started

- Installation manual
  - Developing a new fantastico project
  - Contributing to fantastico framework
- Fantastico settings
  - Settings API
  - Create Dev configuration
  - Using a specifc configuration
- Contribute
  - Code contribution
- Development mode
  - Hot deploy
  - API
  - Database config